var geodashboardRoot = require('system').env['PWD'];
var app = require(geodashboardRoot + '/app.json');

casper.test.begin('Geodashboard Compare View', 11, function suite(test) {
  // note the number above. this needs to match the number of tests

    var url, screenshotRoot, modules, phantomCSS, page;

    url             = "http://localhost:9000/#compare";
    screenshotRoot  = 'results/screenshots';
    modules         = geodashboardRoot + '/node_modules';
    phantomCSS      = require(modules + '/phantomcss/phantomcss.js');
    page            = { width: 1024, height: 768 };

    phantomCSS.init({
      screenshotRoot: screenshotRoot,
      failedComparisonsRoot: screenshotRoot + '/failures',
      libraryRoot: modules + '/phantomcss',
      cleanupComparisonImages: true,
      comparisonResultRoot: screenshotRoot + '/results'
    });

    casper.start(url);
    casper.viewport(page.width, page.height);
    casper.options.waitTimeout = 15000; // set a 15 second timeout

    casper.waitFor(function inspectCompareView() {
        return this.evaluate(function() {
            return document.querySelector('#compare-view');
        });
    }, function then() {
        test.assertTitle(app.title + " - Compare", "The title shows " + app.title + " - Compare");
        test.assertExists("#compare-sidebar", "The #compare-sidebar div is found.");
        test.assertExists("#compare-graph", "The #compare-graph div is found.");

        var sensorsLength = this.page.evaluate(function () {
          var s = new window.Backbone.Collection;
          _.each(window.app.collection.sources.getAreas(), function(area) { _.each(area.areas, function(innerArea) { s.add(innerArea.sensors) }) });
          return s.length;
        });
        test.assertElementCount('button.compare-pill', sensorsLength);

        //phantomCSS.screenshot('#appContainer', 'app-container');


    });

//    TODO - break this into dynamic functions
//    https://github.com/n1k0/casperjs/blob/master/samples/dynamic.js
//    
//    casper.waitFor(function checkSources() {
//        return this.evaluate(function () {
//            return document.querySelector('#search-body');
//        });
//    }, function then() {
//
//        var sources = this.page.evaluate(function() {
//            return window.app.collection.sources.toJSON();
//        });
//
//        for (var i = 0; i < sources.length; i++) {
//            (function (e) {
//                // Select a source
//                casper.then(function () {
//                    this.click('#source-' + sources[e].id);
//                });
//
//                casper.waitFor(function selectSourceSensors() {
//                    return this.evaluate(function () {
//                        console.log('#source-' + sources[e].id);
//                        return document.querySelector('#source-' + sources[e].id).checked == true;
//                    });
//                }, function then() {
//                    test.assertElementCount('g > path[fill="' + sources[e].color + '"]', sources[e].sensors.length);
//                    test.assertSelectorHasText('div#searchResults', 'Sites: ' + sources[e].sensors.length);
//                    test.assertSelectorHasText('div.badge', sources[e].id);
//                    phantomCSS.screenshot('#search-map', 'search-map-' + sources[e].id + '-checked');
//                });
//
//                // Deselecting EPA Sensors
//                casper.then(function () {
//                    this.click('#source-' + sources[e].id);
//                });
//
//                casper.waitFor(function doDeselect() {
//                    return this.evaluate(function () {
//                        return document.querySelector('#source-' + sources[e].id).checked == false;
//                    });
//                }, function then() {
//                    test.assertElementCount('g > path[fill="' + sources[e].color + '"]', 0);
//                    test.assertElementCount('div.badge', 0);
//                    test.assertSelectorHasText('div#searchResults', 'Sites: 0');
//                });
//            })(i);
//        }
//
//    });


//    bamboo won't compare screenshots since the screenshots folder is empty on each new build
//    uncomment this if you want to compare screenshots
//    casper.then( function now_check_the_screenshots(){
//      // compare screenshots
//      phantomCSS.compareAll();
//    });

    /*
     Casper runs tests
     */
    casper.run(function(){
      test.done();
      console.log('\nTHE END.');
      phantom.exit(phantomCSS.getExitStatus());
    });

});
